# example6.c
#
# This example illustrates opening a data file, inserting data from
# the file into a newly created table containing several SQL Server
# datatypes, and updating the table using browse-mode techniques.
import sys
from mssqldb import *

import exutils

print "Demo of SQL queries in a command batch\n"

# Initialize DB-Library.
if not dbinit():
    sys.exit(1)

# Install the user-supplied error-handling and message-handling
# routines. They are defined at the bottom of this source file.
dberrhandle(exutils.err_handler)
dbmsghandle(exutils.msg_handler)

# Allocate and initialize the LOGINREC structure to be used to open a
# connection to SQL Server.
login = dblogin()
login.dbsetluser(exutils.USER)
login.dbsetlpwd(exutils.PASSWORD)
login.dbsetlapp("example6")

q_dbproc = login.dbopen(exutils.SERVER)
u_dbproc = login.dbopen(exutils.SERVER)

print "Creating the 'alltypes' table."

# Create a table that contains several SQL Server data types.
q_dbproc.dbcmd("create table alltypes ")
q_dbproc.dbcmd("(age tinyint,")
q_dbproc.dbcmd("userid smallint,")
q_dbproc.dbcmd("royalty int,")
q_dbproc.dbcmd("name char(25),")
q_dbproc.dbcmd("title_id varbinary(20),")
q_dbproc.dbcmd("us_citizen bit,")
q_dbproc.dbcmd("account float,")
q_dbproc.dbcmd("title varchar(20),")
q_dbproc.dbcmd("manager char(25),")
q_dbproc.dbcmd("timestamp)")

q_dbproc.dbcmd("create unique index index1 on alltypes(userid)")

q_dbproc.dbsqlexec()
while q_dbproc.dbresults() != NO_MORE_RESULTS:
    pass

# Insert rows of data into the newly created table "alltypes".  We
# will read in the contents of the file and form an INSERT statement.
infile = open("datafile")

print "Inserting rows into the 'alltypes' table..."

while 1:
    cmdbuf = infile.readline()
    if not cmdbuf:
        break
    q_dbproc.dbcmd("insert into alltypes\n");
    q_dbproc.dbcmd("values(%s, null) \n" % cmdbuf)
q_dbproc.dbsqlexec()

# Process the results of each of the INSERT statements.
while 1:
    return_code = q_dbproc.dbresults()
    if return_code == NO_MORE_RESULTS:
        break
    if return_code == FAIL:
        print "One of the insert statements FAILed."

# Using DB-Library's browse-mode facilities, we'll increment the age
# of every person in the table.
print "Updating rows in the 'alltypes' table..."

q_dbproc.dbcmd("select * from alltypes for browse")
q_dbproc.dbsqlexec()

while 1:
    return_code = q_dbproc.dbresults()
    if return_code == NO_MORE_RESULTS:
        break
    if return_code == SUCCEED:
        age = DataBuf(SQLINT1)
        while q_dbproc.dbnextrow() != NO_MORE_ROWS:
            q_dbproc.dbdata(age, 1)
            qual = q_dbproc.dbqual("alltypes")
            if not qual:
                print "dbqual() failed.  Exiting."
                dbexit()
                sys.exit(1)
            u_dbproc.dbcmd("update alltypes")
            u_dbproc.dbcmd(" set age = %d %s" % (age.get() + 1, qual))
            u_dbproc.dbsqlexec()
            u_dbproc.dbresults()

# Now, we'll look at the updated contents of the table, to verify that
# the ages were properly incremented.
print "Selecting rows from the 'alltypes' table:"
q_dbproc.dbcmd("select * from alltypes")
q_dbproc.dbsqlexec()
q_dbproc.dbresults()
q_dbproc.dbprrow()

dbexit()
